@@ -334,23 +334,23 @@ function mark_read_show_options_do() {
          echo ') { if (list.options[i].selected) list.options[i].selected=false; else list.options[i].selected=true; } } return false">'._("Toggle Special Folders").'</a><br><br>'
             . '&nbsp;&nbsp;<a href="#" onClick="list=document.mark_read_links_form.elements[1]; for (i=0; i<list.length; i++) {if (list.options[i].selected) list.options[i].selected=false; else list.options[i].selected=true; } return false">'._("Toggle All").'</a></TD></TR></TABLE>';
          
-         echo _("Display links").': <select name="mark_read_display" size="1">'.
-               '<option '.($mark_read_display==0?'selected ':'').'value="0">'._("none").'</option>'.
-               '<option '.($mark_read_display==1?'selected ':'').'value="1">'._("read").'</option>'.
-               '<option '.($mark_read_display==2?'selected ':'').'value="2">'._("unread").'</option>'.
-               '<option '.($mark_read_display==3?'selected ':'').'value="3">'._("read/unread").'</option>'.
+         echo _("Display links") .': <select name="mark_read_display" size="1">'.
+               '<option '.($mark_read_display==0?'selected ':'').'value="0">'. _("none") .'</option>'.
+               '<option '.($mark_read_display==1?'selected ':'').'value="1">'. _("read") .'</option>'.
+               '<option '.($mark_read_display==2?'selected ':'').'value="2">'. _("unread") .'</option>'.
+               '<option '.($mark_read_display==3?'selected ':'').'value="3">'. _("read/unread") .'</option>'.
                '</select>' ;
 
-echo '&nbsp;&nbsp;<input type="radio" name="mark_read_display_upper" value="1" id="mark_read_upper" ' . ($mark_read_display_upper==1?'checked ':' ') . '>';
-echo _("upper");
-echo '<input type="radio" name="mark_read_display_upper" value="0" id="mark_read_display_upper" ' . ($mark_read_display_upper==0?'checked ':' ') . '>'; 
-echo _("lower");
+         echo '&nbsp;&nbsp;<input type="radio" name="mark_read_display_upper" value="1" id="mark_read_upper" ' . ($mark_read_display_upper==1?'checked ':' ') . '>';
+         echo _("upper");
+         echo '<input type="radio" name="mark_read_display_upper" value="0" id="mark_read_display_upper" ' . ($mark_read_display_upper==0?'checked ':' ') . '>'; 
+         echo _("lower");
 
          echo '&nbsp;&nbsp;<input type="checkbox" name="mark_read_display_is_short" value="1" '.($mark_read_display_is_short==1?'checked="checked"':'').' /> '.
-               _("shortened Display")."<BR \>";
+               _("shortened")."<BR \>";
 
-         echo _("brackets").': <select name="user_mark_read_brackets" size="1">'.
-               '<option '.($user_mark_read_brackets==0?'selected ':'').'value="0">'._("none").'</option>'.
+         echo _("brackets") .': <select name="user_mark_read_brackets" size="1">'.
+               '<option '.($user_mark_read_brackets==0?'selected ':'').'value="0">'. _("none") .'</option>'.
                '<option '.($user_mark_read_brackets==1?'selected ':'').'value="1">'."( )".'</option>'.
                '<option '.($user_mark_read_brackets==2?'selected ':'').'value="2">'."[ ]".'</option>'.
                '<option '.($user_mark_read_brackets==3?'selected ':'').'value="3">'."{ }".'</option>'.
@@ -371,6 +371,9 @@ echo _("lower");
                '</select>' ;
          echo "<BR \>";
 
+         # $mark_read_displayall may be unset, so initialize it with the default value
+         if( !isset($mark_read_displayall) ) $mark_read_displayall = $default_mark_read_displayall;
+
          echo '<input type="checkbox" name="mark_read_displayall" value="1" '.($mark_read_displayall==1?'checked="checked"':'').' /> '.
                _("Display 'mark all folders' link below the folder list");
       }
