@@ -51,7 +51,7 @@ function mark_read_show_link_all_read() {
 
 function mark_read_version() {
 
-  return '1.3';
+  return '1.4.1';
 
 }
 
